optInForErrorNotifier method

  1. @override
Future<void> optInForErrorNotifier()
override

Registers the platform to receive error notifications from the SDK.

This method should be implemented to set up the necessary listeners for SDK error notifications on the native platform.

Implementation

@override
Future<void> optInForErrorNotifier() async {
  try {
    await methodChannel.invokeMethod('optInForErrorNotifier');
  } on PlatformException catch (e) {
    log("Error opting in for event notifier: ${e.message}");
    rethrow; // Re-throw the exception to be handled in Flutter.
  }
}